Introduction
------------

The DatPy community is committed to providing an inclusive,
safe, and collaborative environment for all participants, regardless of their
gender, gender expression, race, ethnicity, religion, sexual orientation,
sexual characteristics, physical appearance, disability, or age. We encourage
every participant to be themselves, and must respect the rights of others. The
code of conduct is a set of guidelines that establishes shared values and
ensures that behaviors that may harm participants are avoided.

The values of the DatPy community are focused on developing
both our individual and collective potential, supporting and empowering the
most marginalized, mutual respect, and an anti-violence approach that favors
support and collaboration among participants and the resolution of conflicts. A
code of conduct helps us co-exist in a more positive way and provides
individuals who are victims of negative behaviors with confidence that they
will be supported by the organization and the DatPy
community, who respects and stands behind the code of conduct.

The DatPy community works towards providing a welcoming
environment where participants are treated with dignity and respect and are
free to be themselves. We encourage all participants to approach the
Librehosters network with an open and positive attitude, engaging
constructively with others at all times.

Respect for Diversity & Inclusion
---------------------------------

We avoid comments, actions or propaganda that encourage discrimination related
to gender, gender expression, race, ethnicity, religion, sexual orientation,
sexual characteristics, physical appearance, disability, or age.

Respect Freedom of Expression
-----------------------------

We support an individual's freedom of expression, and will not make fun of
accents or make unsolicited grammatical corrections. We will strive to better
understand each other by not assuming experiences or beliefs, clarifying
meanings, and making an effort to speak clearly, avoiding jargon and acronyms.

Commitment to Non-Violence
--------------------------

We will not engage in any type of violence or aggression, including verbal
threats or complaints, intimidation, stalking or harassment, whether physically
or psychologically.

Rejection of Sexual Harassment
------------------------------

We understand sexual harassment as unwanted physical contact or insinuation of
a sexual nature, as well as displaying images, drawings or visual
representations of any kind that objectify members of any gender or reinforce
oppression. The only exception is if this is part of a session, workshop and/or
educational experience where showing these images is educational in nature.

Respect for Privacy
-------------------

We safeguard the privacy of the participants. This includes refraining from
posting or publishing information about attendees (including names and
affiliation) unless given clear permission, and avoid any type of unauthorized
video, audio recording, or photography.

Facilitate Participation & Collaboration
----------------------------------------

We work to create an environment that facilitates participation for all
participants. We will not engage in sustained disruption of discussions or
events, interrupt conversations in a way that negatively impacts collaboration,
or engage in toxic behaviours to attract negative attention to a participant.

We Care about the Integrity and Health of the Community
-------------------------------------------------------

We value the health of the community and will not engage in behaviour that can
negatively impact it. This includes contaminating food or drink with drugs, or
inciting or insisting on the consumption of alcohol, psychoactive substances,
etc.

Support Positive Interactions Among Participants
------------------------------------------------

We are committed to engaging constructively with others at all times. We will
not tolerate bullying, including requesting or mobilizing others, either in
person or online, to bully others.

Enforcement
-----------

Overseeing the code of conduct
==============================

The DatPy community, composed of volunteers, oversees the
code of conduct, including addressing all incident reports. Breaking the code
of conduct may result in immediate expulsion from the Librehosters network.

How to Report an Incident
=========================

If you witness an incident or are the victim of one:

1. You can reach out directly via email at lukewm@riseup.net.

Acknowledgements
----------------

This code of conduct is inspired by the [IFF CoC].

[IFF CoC]: https://www.internetfreedomfestival.org/wiki/index.php/Code_of_Conduct
